"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOptionsFromRootManifest = void 0;
const error_1 = require("@pnpm/error");
const map_1 = __importDefault(require("ramda/src/map"));
function getOptionsFromRootManifest(manifest) {
    // We read Yarn's resolutions field for compatibility
    // but we really replace the version specs to any other version spec, not only to exact versions,
    // so we cannot call it resolutions
    const overrides = (0, map_1.default)(createVersionReferencesReplacer(manifest), manifest.pnpm?.overrides ?? manifest.resolutions ?? {});
    const neverBuiltDependencies = manifest.pnpm?.neverBuiltDependencies;
    const onlyBuiltDependencies = manifest.pnpm?.onlyBuiltDependencies;
    const packageExtensions = manifest.pnpm?.packageExtensions;
    const peerDependencyRules = manifest.pnpm?.peerDependencyRules;
    const allowedDeprecatedVersions = manifest.pnpm?.allowedDeprecatedVersions;
    const allowNonAppliedPatches = manifest.pnpm?.allowNonAppliedPatches;
    const patchedDependencies = manifest.pnpm?.patchedDependencies;
    const settings = {
        allowedDeprecatedVersions,
        allowNonAppliedPatches,
        overrides,
        neverBuiltDependencies,
        packageExtensions,
        peerDependencyRules,
        patchedDependencies,
    };
    if (onlyBuiltDependencies) {
        settings['onlyBuiltDependencies'] = onlyBuiltDependencies;
    }
    return settings;
}
exports.getOptionsFromRootManifest = getOptionsFromRootManifest;
function createVersionReferencesReplacer(manifest) {
    const allDeps = {
        ...manifest.devDependencies,
        ...manifest.dependencies,
        ...manifest.optionalDependencies,
    };
    return replaceVersionReferences.bind(null, allDeps);
}
function replaceVersionReferences(dep, spec) {
    if (!spec.startsWith('$'))
        return spec;
    const dependencyName = spec.slice(1);
    const newSpec = dep[dependencyName];
    if (newSpec)
        return newSpec;
    throw new error_1.PnpmError('CANNOT_RESOLVE_OVERRIDE_VERSION', `Cannot resolve version ${spec} in overrides. The direct dependencies don't have dependency "${dependencyName}".`);
}
//# sourceMappingURL=getOptionsFromRootManifest.js.map